import { NextFunction, Request, Response } from "express";
import { Query, Params } from 'express-serve-static-core';
import mongoose from 'mongoose';
interface InputValidations {
    validate: (request: Request, response: Response, next: NextFunction) => {};
}
interface TypedRequest<P extends Params, T extends Query, U> extends Express.Request {
    query: T;
    body: U;
    params: P;
}
interface Date {
    date: string;
    month: string;
    year: string;
}
interface DateAndTime extends Date {
    time: string;
}
interface RatioTemplate {
    url: string;
}
interface ThumbnailTemplate {
    web: Thumbnail;
    mobile: Thumbnail;
}
interface Thumbnail {
    original: RatioTemplate;
    cdn: RatioTemplate;
}
interface BannerTemplate {
    web: Banner;
}
interface Banner {
    original: RatioTemplate;
    cdn: RatioTemplate;
}
interface Cast {
    name: string;
    role: string;
    profilePic: string;
    description: string;
}
declare enum Currency {
    USD = "USD"
}
declare enum Audience {
    MEMBER = "MEMBER",
    CITIZEN = "CITIZEN",
    ELDER = "ELDER"
}
interface OtherCategory extends mongoose.Document {
    name: string;
}
declare const ratioTemplateSchema: mongoose.Schema<RatioTemplate, any, any, any>;
declare const thumbnailsSubSchema: mongoose.Schema<Thumbnail, any, any, any>;
declare const bannersSubSchema: mongoose.Schema<Banner, any, any, any>;
declare const thumbnailTemplateSchema: mongoose.Schema<ThumbnailTemplate, any, any, any>;
declare const bannerTemplateSchema: mongoose.Schema<BannerTemplate, any, any, any>;
declare const castSubSchema: mongoose.Schema<Cast, any, any, any>;
declare const OtherCategorySubSchema: mongoose.Schema<OtherCategory, any, any, any>;
declare const contactSchema: mongoose.Schema<any, mongoose.Model<any, any, any, any>, any, any>;
interface Contact {
    code: string;
    number: string;
}
declare enum Extensions {
    JPG = "jpg",
    JPEG = "jpeg",
    PNG = "png"
}
declare enum MimeTypes {
    JPG = "image/jpg",
    JPEG = "image/jpeg",
    PNG = "image/png"
}
declare enum VideoExtensions {
    MP4 = "mp4",
    MOV = "mov"
}
declare enum VideoMimeTypes {
    MP4 = "video/mp4",
    QUICKTIME = "video/quicktime"
}
declare enum SubtitlesExtensions {
    SRT = "srt"
}
declare enum SubtitlesMimeTypes {
    SRT = "application/x-subrip"
}
declare enum AudioTracksExtensions {
    MP3 = "mp3"
}
declare enum AudioTracksMimeTypes {
    MPEG = "audio/mpeg"
}
declare enum ChunkStatus {
    PENDING = "PENDING",
    INVALID_CHUNK = "INVALID_CHUNK",
    COMPLETED = "COMPLETED"
}
interface Chunk extends mongoose.Document {
    status: ChunkStatus;
    size: number;
}
export { InputValidations, TypedRequest, Date, DateAndTime, RatioTemplate, ThumbnailTemplate, Thumbnail, BannerTemplate, Banner, Cast, ratioTemplateSchema, thumbnailsSubSchema, bannersSubSchema, thumbnailTemplateSchema, bannerTemplateSchema, castSubSchema, Currency, Audience, OtherCategory, OtherCategorySubSchema, contactSchema, Contact, Extensions, MimeTypes, VideoExtensions, VideoMimeTypes, SubtitlesExtensions, SubtitlesMimeTypes, AudioTracksExtensions, AudioTracksMimeTypes, ChunkStatus, Chunk };
