import mongoose from 'mongoose';
import { ChannelStaffRoles } from './channel-staff';
import { EventPayment, EventTicketCost } from './event';
import { UserAvatar } from './user';
export declare enum TransactionType {
    CREDIT = "CREDIT",
    DEBIT = "DEBIT"
}
export declare enum TransactionSubType {
    CAPTURE = "CAPTURE",
    REFUND = "REFUND",
    CHANNEL_OWNER_DISBURSEMENT = "CHANNEL_OWNER_DISBURSEMENT",
    OWNER_DISBURSEMENT = "OWNER_DISBURSEMENT"
}
export declare enum TransactionStripePaymentStatus {
    PAID = "paid",
    UNPAID = "unpaid",
    NO_PAYMENT_REQUIRED = "no_payment_required"
}
export declare enum TransactionStripeDisbursementStatus {
    PAID = "paid",
    PENDING = "pending",
    IN_TRANSIT = "in_transit",
    CANCELED = "canceled",
    FAILED = "failed"
}
export declare enum TransactionStripeRefundStatus {
    PENDING = "pending",
    REQUIRES_ACTION = "requires_action",
    SUCCEEDED = "succeeded",
    FAILED = "failed",
    CANCELED = "canceled"
}
export declare enum TransactionDisbursementStatus {
    NOT_STARTED = "NOT_STARTED",
    IN_PROGRESS = "IN_PROGRESS",
    COMPLETED = "COMPLETED",
    FAILED = "FAILED"
}
export declare enum TransactionRefundStatus {
    NOT_STARTED = "NOT_STARTED",
    IN_PROGRESS = "IN_PROGRESS",
    COMPLETED = "COMPLETED",
    FAILED = "FAILED"
}
export declare enum TransactionPaymentModes {
    STRIPE = "STRIPE",
    OCULUS_IN_APP = "OCULUS_IN_APP"
}
export declare enum TransactionOculusPaymentStatus {
    PAID = "paid"
}
export interface TransactionUser extends mongoose.Document {
    userId: mongoose.Types.ObjectId;
    displayName: string;
    email: string;
    role: string;
    avatar?: UserAvatar;
}
export interface TransactionEvent extends mongoose.Document {
    eventId: mongoose.Types.ObjectId;
    name: string;
    type: string;
    venue?: string;
    category: string;
    startTime: Date;
    endTime: Date;
    ticketCost?: EventTicketCost;
    payment?: EventPayment;
}
export interface DisbursementTransactions extends mongoose.Document {
    transactionId: mongoose.Types.ObjectId;
    chargeId: string;
    currency: string;
    price: number;
}
export interface TransactionApprovedChannel extends mongoose.Document {
    approvedChannelId: mongoose.Types.ObjectId;
    name: string;
}
export interface TransactionChannelStaff extends mongoose.Document {
    channelStaffId: mongoose.Types.ObjectId;
    displayName: string;
    email: string;
    role: ChannelStaffRoles;
    profilePic?: string;
}
export interface TransactionAccountDetails extends mongoose.Document {
    accountId: string;
}
export interface TransactionRefund extends mongoose.Document {
    refundId?: string;
    currency?: string;
    amount?: number;
    coins?: number;
}
export interface TransactionDisbursement extends mongoose.Document {
    disbursementId?: string;
    currency: string;
    amount: number;
}
export interface TransactionCharge extends mongoose.Document {
    chargeId?: string;
    currency?: string;
    amount?: number;
    coins?: number;
}
export interface ITransactionDisbursementStatus extends mongoose.Document {
    owner?: TransactionDisbursementStatus;
    channelOwner?: TransactionDisbursementStatus;
}
export declare const transactionUserSubSchema: mongoose.Schema<TransactionUser, any, any, any>;
export declare const transactionEventSubSchema: mongoose.Schema<TransactionEvent, any, any, any>;
export declare const disbursementTransctionsSubSchema: mongoose.Schema<DisbursementTransactions, any, any, any>;
export declare const transactionApprovedChannelSubSchema: mongoose.Schema<TransactionApprovedChannel, any, any, any>;
export declare const transactionChannelStaffSubSchema: mongoose.Schema<TransactionChannelStaff, any, any, any>;
export declare const transactionAccountDetailsSubSchema: mongoose.Schema<TransactionAccountDetails, any, any, any>;
export declare const transactionRefundSubSchema: mongoose.Schema<TransactionRefund, any, any, any>;
export declare const transactionDisbursementSubSchema: mongoose.Schema<TransactionDisbursement, any, any, any>;
export declare const transactionChargeSubSchema: mongoose.Schema<TransactionCharge, any, any, any>;
export declare const transactionDisbursementStatusSchema: mongoose.Schema<ITransactionDisbursementStatus, any, any, any>;
