import { Request, Response, NextFunction } from 'express';
import { Model } from 'mongoose';
interface UserPayload {
    sub: string;
    azp: string;
    name: string;
    preferred_username: string;
    given_name: string;
    family_name: string;
    email: string;
    typ: 'Bearer';
    realm_access: object;
    resource_access: object;
}
interface CurrentUser<T> {
    user: T;
}
interface AuthMiddleware {
    checkCurrentUser<T>(req: Request, User: Model<T>): Promise<Record<string, any>>;
    currentUser<T>(User: Model<T>): (req: Request, res: Response<any, CurrentUser<T>>, next: NextFunction) => {};
    checkCurrentStaff<T>(req: Request, Staff: Model<T>): Promise<Record<string, any>>;
    currentStaff<T>(Staff: Model<T>): (req: Request, res: Response<any, CurrentUser<T>>, next: NextFunction) => {};
    checkCurrentChannelStaff<ChannelStaff, ChannelStaffRole>(req: Request, ChannelStaff: Model<ChannelStaff>, ChannelStaffRole: Model<ChannelStaffRole>): Promise<Record<string, any>>;
    currentChannelStaff<ChannelStaff, ChannelStaffRole>(ChannelStaff: Model<ChannelStaff>, ChannelStaffRole: Model<ChannelStaffRole>): (req: Request, res: Response<any, CurrentUser<ChannelStaff>>, next: NextFunction) => {};
}
declare class AuthMiddleware implements AuthMiddleware {
    private static _instance;
    private constructor();
    static getInstance(): AuthMiddleware;
    /**
     * To config the keycloak with authorized user.
     * @param realm - The name of the realm
     * @param authUrl - The url of federated identity
     * @param clientId - Name of the client
     * @param clientSecret - The secret id of the client
     * @param username - Username of the admin
     * @param password - Password of the admin
     * @returns The keycloak config
     */
    private keycloakConfig;
    /**
     * Decode the access token by the jsonwebtoken package.
     * @param accessToken - Access token from the header
     * @returns The decoded user payload
     */
    private decodeAccessToken;
    /**
     * Verify the access token with online by keycloak.
     * @param accessToken - Access token from the header
     * @returns The online verified user payload
     */
    private verifyOnlineAccessToken;
    /**
     * Verify the access token with offline by keycloak.
     * @param accessToken - Access token from the header
     * @returns The offline verified user payload
     */
    private verifyOfflineAccessToken;
}
export { UserPayload, CurrentUser, AuthMiddleware };
