"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mongooseErrorHandler = exports.mongooseValidationErrors = exports.mongooseServerErrors = void 0;
var __1 = require("..");
var mongooseServerErrors = function (err) {
    var message = "";
    switch (err.code) {
        case 11000: {
            if (err.keyValue && Object.keys(err.keyValue)[0])
                message = "".concat(Object.keys(err.keyValue)[0], " already exists, please try again");
            else
                message = "Some of the provided values already exists, please try again with different values.";
            break;
        }
        default: {
            message = 'Something went wrong, please try again.';
        }
    }
    ;
    return message;
};
exports.mongooseServerErrors = mongooseServerErrors;
var mongooseValidationErrors = function (err) {
    try {
        var invalidKey_1 = Object.keys(err.errors)[0];
        if (err.errors[invalidKey_1].kind === 'user defined' &&
            err.errors[invalidKey_1].reason)
            throw "".concat(err.errors[invalidKey_1].path, " ").concat(err.errors[invalidKey_1].reason.message);
        else if (err.errors[invalidKey_1].kind === 'user defined' ||
            [
                'enum',
                'required',
                'min',
                'max',
                'minLength',
                'maxLength',
                'match',
            ].some(function (ele) { return err.errors[invalidKey_1].kind === ele; }))
            throw "".concat(err.errors[invalidKey_1].path, " ").concat(err.errors[invalidKey_1].message);
        else if (err.errors[invalidKey_1].kind === 'ObjectId')
            throw "".concat(err.errors[invalidKey_1].path, " should be an ObjectId but got ").concat(typeof err.errors[invalidKey_1].value);
        else if (err.errors[invalidKey_1].kind === '[ObjectId]')
            throw "".concat(err.errors[invalidKey_1].path, " should be an ObjectId but got ").concat(typeof err.errors[invalidKey_1].value);
        return "Something went wrong, please try again.";
    }
    catch (error) {
        return error;
    }
    ;
};
exports.mongooseValidationErrors = mongooseValidationErrors;
var mongooseErrorHandler = function (err, request, response, next) {
    if (err.name) {
        if (err.name === 'MongoServerError') {
            var message = (0, exports.mongooseServerErrors)(err);
            next(new __1.GenericValidationError({ error: new Error(message), errorCode: 400 }));
        }
        else if (err.name === 'ValidationError') {
            var message = (0, exports.mongooseValidationErrors)(err);
            next(new __1.GenericValidationError({ error: new Error(message), errorCode: 400 }));
        }
        else
            next(err);
    }
    else
        next(err);
};
exports.mongooseErrorHandler = mongooseErrorHandler;
