import RoleRepresentation from 'keycloak-admin/lib/defs/roleRepresentation';
import { UserQuery } from 'keycloak-admin/lib/resources/users';
import UserRepresentation from 'keycloak-nodejs-admin-client/lib/defs/userRepresentation';
import { SSOUserClient, SSOUserRole } from '../interfaces';
interface SSODatabaseService {
    saveUser(userData: UserRepresentation): Promise<string>;
    updateUser(ssoId: string, query: any): Promise<void>;
    findUser(query: UserQuery): Promise<UserRepresentation[]>;
    findUserById(ssoId: string): Promise<UserRepresentation>;
    deleteUser(ssoId: string): Promise<void>;
    addUserRole(roleInfo: SSOUserRole): Promise<void>;
    listUserRole(roleInfo: SSOUserClient): Promise<RoleRepresentation[]>;
    deleteUserRole(roleInfo: SSOUserRole): Promise<void>;
    logoutUser(ssoId: string): Promise<void>;
}
declare class SSOService implements SSODatabaseService {
    private static _instance;
    private _ssoConnect;
    private constructor();
    static getInstance(): SSOService;
    /**
     * Save the user data initially.
     * @param userData
     * @returns
     */
    saveUser(userData: UserRepresentation): Promise<string>;
    /**
     * Get all the users that match the query
     * @param query
     * @returns
     */
    findUser(query: UserQuery): Promise<import("keycloak-admin/lib/defs/userRepresentation").default[]>;
    /**
     * Get the user by the sso id
     * @param ssoId
     * @returns
     */
    findUserById(ssoId: string): Promise<import("keycloak-admin/lib/defs/userRepresentation").default>;
    /**
     * Update the user based on the SSOId.
     * @param ssoId
     * @param query
     */
    updateUser(ssoId: string, query: any): Promise<void>;
    /**
     * Deleting the user based on id
     * @param ssoId - Unique user id from sso server
     */
    deleteUser(ssoId: string): Promise<void>;
    /**
     * Add the client roles for user
     * @param roleInfo
     */
    addUserRole(roleInfo: SSOUserRole): Promise<void>;
    /**
     * List the client roles for user
     * @param roleInfo
     */
    listUserRole(roleInfo: SSOUserClient): Promise<RoleRepresentation[]>;
    /**
 * Delete the client roles for user
 * @param roleInfo
 */
    deleteUserRole(roleInfo: SSOUserRole): Promise<void>;
    logoutUser(ssoId: string): Promise<void>;
}
export { SSOService, SSODatabaseService };
