/// <reference types="node" />
import { S3 } from 'aws-sdk';
import { ResponseHandler } from '../helpers';
export declare abstract class CommonStorageService extends ResponseHandler {
    constructor();
    abstract getFileURLFromKey(key: string): string;
    abstract getSignedURL(key: string, expires?: string, objType?: 'getObject' | 'putObject', uploadId?: string, partNumber?: number): Promise<string>;
    abstract getObjectKey(fileURL: string): string;
    abstract addObjectLock(key: string): Promise<S3.PutObjectLegalHoldOutput>;
    abstract removeObjectLock(key: string): Promise<S3.PutObjectLegalHoldOutput>;
    abstract getObject(key: string): Promise<S3.Body | undefined>;
    abstract putObject(key: string, body: Buffer): Promise<S3.PutObjectOutput>;
    abstract putObjectTagging(key: string, tagSet: S3.TagSet): Promise<S3.PutObjectTaggingOutput>;
    abstract createMultipartUpload(key: string): Promise<S3.CreateMultipartUploadOutput>;
    abstract listParts(key: string, uploadId: string, partNumberMarker?: number, maxParts?: number): Promise<S3.ListPartsOutput>;
    abstract upload(key: string, body: Buffer): Promise<S3.PutObjectOutput>;
}
export declare abstract class BaseStorageService extends CommonStorageService {
    private _s3StorageConnect;
    private _storage;
    private _nconf;
    constructor();
    abstract getFilePath<FileType, FileSubType>(access: 'public' | 'private', fileSubType: FileSubType, fileType: FileType, extension: string, userIdObj: Record<string, any> | null): string;
    abstract returnMimeType(fileURL: string): string;
    abstract returnExtension(mimeType: string): string;
    /**
     * Get file URL from object key.
     * @param key
     * @returns string
     */
    getFileURLFromKey(key: string): string;
    /**
     *
     * @param key example path : 'output.zip'
     * @param expires
     * @param objType
     * @param uploadId
     * @param partNumber
     * @description To get signedURL for viewing and updating an object.
     * @returns Promise<string>
     */
    getSignedURL(key: string, expires?: any, objType?: 'getObject' | 'putObject' | 'uploadPart', uploadId?: string, partNumber?: number): Promise<string>;
    /**
     *
     * @param fileURL example: https://s3.terrahost.com/bucketName/public/users/user_id/avatar/model.zip
     * @returns example: public/users/user_id/avatar/model.zip
     */
    getObjectKey(fileURL: string): string;
    /**
     *
     * @param key example: /public/users/user_id/avatar/model.zip
     * @returns Lock will be added for the particular object.
     */
    addObjectLock(key: string): Promise<S3.PutObjectLegalHoldOutput>;
    /**
     *
     * @param key example: /public/users/user_id/avatar/model.zip
     * @returns Lock will be removed for the particular object.
     */
    removeObjectLock(key: string): Promise<S3.PutObjectLegalHoldOutput>;
    getObject(key: string): Promise<S3.Body | undefined>;
    putObject(key: string, body: Buffer): Promise<S3.PutObjectOutput>;
    putObjectTagging(key: string, tagSet: S3.TagSet): Promise<S3.PutObjectTaggingOutput>;
    createMultipartUpload(key: string): Promise<S3.CreateMultipartUploadOutput>;
    listParts(key: string, uploadId: string, partNumberMarker?: number, maxParts?: number): Promise<S3.ListPartsOutput>;
    completeMultipartUpload(key: string, uploadId: string, parts: S3.CompletedPartList): Promise<S3.CompleteMultipartUploadOutput>;
    upload(key: string, body: Buffer): Promise<S3.PutObjectOutput>;
}
