import Stripe from 'stripe';
interface BaseStripeService {
    createCustomer(sourceParams?: Stripe.CustomerCreateParams): Promise<Stripe.Response<Stripe.Customer>>;
    retrieveCustomer(customerId: string): Promise<Stripe.Response<Stripe.Customer | Stripe.DeletedCustomer>>;
    updateCustomer(customerId: string, updateParams?: Stripe.CustomerUpdateParams): Promise<Stripe.Response<Stripe.Customer>>;
    deleteCustomer(customerId: string): Promise<Stripe.Response<Stripe.DeletedCustomer>>;
    listAllCustomers(limit?: number, startingAfter?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.Customer>>>;
    searchCustomers(query: string, limit?: number, page?: string): Promise<Stripe.Response<Stripe.ApiSearchResult<Stripe.Customer>>>;
    createCard(customerId: string, source: string): Promise<Stripe.Response<Stripe.CustomerSource>>;
    retrieveCard(customerId: string, cardId: string): Promise<Stripe.Response<Stripe.CustomerSource>>;
    updateCard(customerId: string, cardId: string, sourceParams: Stripe.CustomerSourceUpdateParams): Promise<Stripe.Response<Stripe.BankAccount | Stripe.Card | Stripe.Source>>;
    deleteCard(customerId: string, cardId: string): Promise<Stripe.Response<Stripe.CustomerSource | Stripe.DeletedAlipayAccount | Stripe.DeletedBankAccount | Stripe.DeletedBitcoinReceiver | Stripe.DeletedCard>>;
    listAllCards(customerId: string, limit?: number, startingAfter?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.CustomerSource>>>;
    createCharge(amount: number, currency: string, source: string, description: string): Promise<Stripe.Response<Stripe.Charge>>;
    retrieveCharge(chargeId: string): Promise<Stripe.Response<Stripe.Charge>>;
    updateCharge(chargeId: string, chargeParams?: Stripe.ChargeUpdateParams): Promise<Stripe.Response<Stripe.Charge>>;
    captureCharge(chargeId: string): Promise<Stripe.Response<Stripe.Charge>>;
    createRefund(chargeId: string, amount: number): Promise<Stripe.Response<Stripe.Refund>>;
    retrieveRefund(refundId: string): Promise<Stripe.Response<Stripe.Refund>>;
    updateRefund(refundId: string, refundParams?: Stripe.RefundUpdateParams): Promise<Stripe.Response<Stripe.Refund>>;
    cancelRefund(refundId: string): Promise<Stripe.Response<Stripe.Refund>>;
    createPayout(payoutParams: Stripe.PayoutCreateParams, options?: Stripe.RequestOptions): Promise<Stripe.Response<Stripe.Payout>>;
    retrievePayout(payoutId: string): Promise<Stripe.Response<Stripe.Payout>>;
    updatePayout(payoutId: string, payoutParams?: Stripe.PayoutUpdateParams, options?: Stripe.RequestOptions): Promise<Stripe.Response<Stripe.Payout>>;
    cancelPayout(payoutId: string): Promise<Stripe.Response<Stripe.Payout>>;
    createSetupIntent(setupIntentParams?: Stripe.SetupIntentCreateParams): Promise<Stripe.Response<Stripe.SetupIntent>>;
    retrieveSetupIntent(setupIntentId: string): Promise<Stripe.Response<Stripe.SetupIntent>>;
    updateSetupIntent(setupIntentId: string, setupIntentParams?: Stripe.SetupIntentUpdateParams): Promise<Stripe.Response<Stripe.SetupIntent>>;
    confirmSetupIntent(setupIntentId: string, setupIntentParams?: Stripe.SetupIntentConfirmParams): Promise<Stripe.Response<Stripe.SetupIntent>>;
    cancelSetupIntent(setupIntentId: string): Promise<Stripe.Response<Stripe.SetupIntent>>;
    listAllSetupIntents(customerId: string, paymentMethod?: string, limit?: number, startingAfter?: string, endingBefore?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.SetupIntent>>>;
    verifySetupIntent(setupIntentId: string, amounts?: number[]): Promise<any>;
    createBankAccount(customerId: string, bankAccountParams: Stripe.CustomerSourceCreateParams): Promise<Stripe.Response<Stripe.CustomerSource>>;
    retrieveBankAccount(customerId: string, bankAccountId: string): Promise<Stripe.Response<Stripe.CustomerSource>>;
    updateBankAccount(customerId: string, bankAccountId: string, bankAccountParams?: Stripe.CustomerSourceUpdateParams): Promise<Stripe.Response<Stripe.BankAccount | Stripe.Card | Stripe.Source>>;
    verifyBankAccount(customerId: string, bankAccountId: string, amounts?: number[]): Promise<Stripe.Response<Stripe.BankAccount>>;
    deleteBankAccount(customerId: string, bankAccountId: string): Promise<Stripe.Response<Stripe.CustomerSource | Stripe.DeletedAlipayAccount | Stripe.DeletedBankAccount | Stripe.DeletedBitcoinReceiver | Stripe.DeletedCard>>;
    listAllBankAccounts(customerId: string, limit?: number, startingAfter?: string, endingBefore?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.CustomerSource>>>;
    listPaymentMethods(customerId: string, type: Stripe.PaymentMethodListParams.Type, limit?: number, startingAfter?: string, endingBefore?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.PaymentMethod>>>;
    listCustomerPaymentMethods(customerId: string, type: Stripe.PaymentMethodListParams.Type, limit?: number, startingAfter?: string, endingBefore?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.PaymentMethod>>>;
    createCheckoutSession(sessionParams: Stripe.Checkout.SessionCreateParams): Promise<Stripe.Response<Stripe.Checkout.Session>>;
    expireCheckoutSession(sessionId: string, sessionParams?: Stripe.Checkout.SessionExpireParams): Promise<Stripe.Response<Stripe.Checkout.Session>>;
    retrieveCheckoutSession(sessionId: string, sessionParams?: Stripe.Checkout.SessionExpireParams): Promise<Stripe.Response<Stripe.Checkout.Session>>;
    listAllCheckoutSessions(limit?: number, startingAfter?: string, endingBefore?: string, expand?: string[]): Promise<Stripe.Response<Stripe.ApiList<Stripe.Checkout.Session>>>;
    createPrice(priceParams: Stripe.PriceCreateParams): Promise<Stripe.Response<Stripe.Price>>;
    retrievePrice(priceId: string): Promise<Stripe.Response<Stripe.Price>>;
    updatePrice(priceId: string, priceParams?: Stripe.PriceUpdateParams): Promise<Stripe.Response<Stripe.Price>>;
    searchPrice(query: string, limit?: number, expand?: string[]): Promise<Stripe.Response<Stripe.ApiSearchResult<Stripe.Price>>>;
    listAllPrices(active?: boolean, type?: Stripe.PriceListParams.Type, currency?: string, product?: string, recurring?: Stripe.PriceListParams.Recurring, limit?: number, startingAfter?: string, endingBefore?: string, expand?: string[]): Promise<Stripe.Response<Stripe.ApiList<Stripe.Price>>>;
    createProduct(productParams: Stripe.ProductCreateParams): Promise<Stripe.Response<Stripe.Product>>;
    retrieveProduct(productId: string): Promise<Stripe.Response<Stripe.Product>>;
    updateProduct(productId: string, productParams?: Stripe.ProductUpdateParams): Promise<Stripe.Response<Stripe.Product>>;
    searchProducts(query: string, limit?: number, expand?: string[]): Promise<Stripe.Response<Stripe.ApiSearchResult<Stripe.Product>>>;
    listAllProducts(active?: boolean, type?: Stripe.ProductListParams.Type, ids?: string[], url?: string, limit?: number, startingAfter?: string, endingBefore?: string, expand?: string[]): Promise<Stripe.Response<Stripe.ApiList<Stripe.Product>>>;
    deleteProduct(productId: string): Promise<Stripe.Response<Stripe.DeletedProduct>>;
    createBankAccountToken(bankAccountTokenParams: Stripe.TokenCreateParams): Promise<Stripe.Response<Stripe.Token>>;
    createAccount(accountParams: Stripe.AccountCreateParams): Promise<Stripe.Response<Stripe.Account>>;
    retrieveAccount(accountId: string): Promise<Stripe.Response<Stripe.Account>>;
    updateAccount(accountId: string, accountParams: Stripe.AccountUpdateParams): Promise<Stripe.Response<Stripe.Account>>;
    rejectAccount(accountId: string, accountRejectedParams: Stripe.AccountRejectParams): Promise<Stripe.Response<Stripe.Account>>;
    deleteAccount(accountId: string, accountDeleteParams?: Stripe.AccountDeleteParams): Promise<Stripe.Response<Stripe.DeletedAccount>>;
    createAccountLink(accountLinkParams: Stripe.AccountLinkCreateParams): Promise<Stripe.Response<Stripe.AccountLink>>;
    createTransfer(transferParams: Stripe.TransferCreateParams): Promise<Stripe.Response<Stripe.Transfer>>;
    retrieveTransfer(transferId: string): Promise<Stripe.Response<Stripe.Transfer>>;
    updateTransfer(transferId: string, transferParams: Stripe.TransferUpdateParams): Promise<Stripe.Response<Stripe.Transfer>>;
}
declare class StripeService implements BaseStripeService {
    private static _instance;
    private _stripe;
    private constructor();
    static getInstance(): BaseStripeService;
    createCustomer(sourceParams?: Stripe.CustomerCreateParams): Promise<Stripe.Response<Stripe.Customer>>;
    retrieveCustomer(customerId: string): Promise<Stripe.Response<Stripe.Customer | Stripe.DeletedCustomer>>;
    updateCustomer(customerId: string, updateParams?: Stripe.CustomerUpdateParams): Promise<Stripe.Response<Stripe.Customer>>;
    deleteCustomer(customerId: string): Promise<Stripe.Response<Stripe.DeletedCustomer>>;
    listAllCustomers(limit?: number, startingAfter?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.Customer>>>;
    searchCustomers(query: string, limit?: number, page?: string): Promise<Stripe.Response<Stripe.ApiSearchResult<Stripe.Customer>>>;
    createCard(customerId: string, source: string): Promise<Stripe.Response<Stripe.CustomerSource>>;
    retrieveCard(customerId: string, cardId: string): Promise<Stripe.Response<Stripe.CustomerSource>>;
    updateCard(customerId: string, cardId: string, sourceParams: Stripe.CustomerSourceUpdateParams): Promise<Stripe.Response<Stripe.BankAccount | Stripe.Card | Stripe.Source>>;
    deleteCard(customerId: string, cardId: string): Promise<Stripe.Response<Stripe.CustomerSource | Stripe.DeletedAlipayAccount | Stripe.DeletedBankAccount | Stripe.DeletedBitcoinReceiver | Stripe.DeletedCard>>;
    listAllCards(customerId: string, limit?: number, startingAfter?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.CustomerSource>>>;
    createCharge(amount: number, currency: string, source: string, description: string): Promise<Stripe.Response<Stripe.Charge>>;
    retrieveCharge(chargeId: string): Promise<Stripe.Response<Stripe.Charge>>;
    updateCharge(chargeId: string, chargeParams?: Stripe.ChargeUpdateParams): Promise<Stripe.Response<Stripe.Charge>>;
    captureCharge(chargeId: string): Promise<Stripe.Response<Stripe.Charge>>;
    createRefund(chargeId: string, amount: number): Promise<Stripe.Response<Stripe.Refund>>;
    retrieveRefund(refundId: string): Promise<Stripe.Response<Stripe.Refund>>;
    updateRefund(refundId: string, refundParams?: Stripe.RefundUpdateParams): Promise<Stripe.Response<Stripe.Refund>>;
    cancelRefund(refundId: string): Promise<Stripe.Response<Stripe.Refund>>;
    createPayout(payoutParams: Stripe.PayoutCreateParams, options?: Stripe.RequestOptions): Promise<Stripe.Response<Stripe.Payout>>;
    retrievePayout(payoutId: string): Promise<Stripe.Response<Stripe.Payout>>;
    updatePayout(payoutId: string, payoutParams?: Stripe.PayoutUpdateParams, options?: Stripe.RequestOptions): Promise<Stripe.Response<Stripe.Payout>>;
    cancelPayout(payoutId: string): Promise<Stripe.Response<Stripe.Payout>>;
    createSetupIntent(setupIntentParams?: Stripe.SetupIntentCreateParams): Promise<Stripe.Response<Stripe.SetupIntent>>;
    retrieveSetupIntent(setupIntentId: string): Promise<Stripe.Response<Stripe.SetupIntent>>;
    updateSetupIntent(setupIntentId: string, setupIntentParams?: Stripe.SetupIntentUpdateParams): Promise<Stripe.Response<Stripe.SetupIntent>>;
    confirmSetupIntent(setupIntentId: string, setupIntentParams?: Stripe.SetupIntentConfirmParams): Promise<Stripe.Response<Stripe.SetupIntent>>;
    cancelSetupIntent(setupIntentId: string): Promise<Stripe.Response<Stripe.SetupIntent>>;
    listAllSetupIntents(customerId: string, paymentMethod?: string, limit?: number, startingAfter?: string, endingBefore?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.SetupIntent>>>;
    verifySetupIntent(setupIntentId: string, amounts?: number[]): Promise<any>;
    createBankAccount(customerId: string, bankAccountParams: Stripe.CustomerSourceCreateParams): Promise<Stripe.Response<Stripe.CustomerSource>>;
    retrieveBankAccount(customerId: string, bankAccountId: string): Promise<Stripe.Response<Stripe.CustomerSource>>;
    updateBankAccount(customerId: string, bankAccountId: string, bankAccountParams?: Stripe.CustomerSourceUpdateParams): Promise<Stripe.Response<Stripe.BankAccount | Stripe.Card | Stripe.Source>>;
    verifyBankAccount(customerId: string, bankAccountId: string, amounts?: number[]): Promise<Stripe.Response<Stripe.BankAccount>>;
    deleteBankAccount(customerId: string, bankAccountId: string): Promise<Stripe.Response<Stripe.CustomerSource | Stripe.DeletedAlipayAccount | Stripe.DeletedBankAccount | Stripe.DeletedBitcoinReceiver | Stripe.DeletedCard>>;
    listAllBankAccounts(customerId: string, limit?: number, startingAfter?: string, endingBefore?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.CustomerSource>>>;
    listPaymentMethods(customerId: string, type: Stripe.PaymentMethodListParams.Type, limit?: number, startingAfter?: string, endingBefore?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.PaymentMethod>>>;
    listCustomerPaymentMethods(customerId: string, type: Stripe.PaymentMethodListParams.Type, limit?: number, startingAfter?: string, endingBefore?: string): Promise<Stripe.Response<Stripe.ApiList<Stripe.PaymentMethod>>>;
    createCheckoutSession(sessionParams: Stripe.Checkout.SessionCreateParams): Promise<Stripe.Response<Stripe.Checkout.Session>>;
    expireCheckoutSession(sessionId: string, sessionParams?: Stripe.Checkout.SessionExpireParams): Promise<Stripe.Response<Stripe.Checkout.Session>>;
    retrieveCheckoutSession(sessionId: string, sessionParams?: Stripe.Checkout.SessionExpireParams): Promise<Stripe.Response<Stripe.Checkout.Session>>;
    listAllCheckoutSessions(limit?: number, startingAfter?: string, endingBefore?: string, expand?: string[]): Promise<Stripe.Response<Stripe.ApiList<Stripe.Checkout.Session>>>;
    createPrice(priceParams: Stripe.PriceCreateParams): Promise<Stripe.Response<Stripe.Price>>;
    retrievePrice(priceId: string): Promise<Stripe.Response<Stripe.Price>>;
    updatePrice(priceId: string, priceParams?: Stripe.PriceUpdateParams): Promise<Stripe.Response<Stripe.Price>>;
    searchPrice(query: string, limit?: number, expand?: string[]): Promise<Stripe.Response<Stripe.ApiSearchResult<Stripe.Price>>>;
    listAllPrices(active?: boolean, type?: Stripe.PriceListParams.Type, currency?: string, product?: string, recurring?: Stripe.PriceListParams.Recurring, limit?: number, startingAfter?: string, endingBefore?: string, expand?: string[]): Promise<Stripe.Response<Stripe.ApiList<Stripe.Price>>>;
    createProduct(productParams: Stripe.ProductCreateParams): Promise<Stripe.Response<Stripe.Product>>;
    retrieveProduct(productId: string): Promise<Stripe.Response<Stripe.Product>>;
    updateProduct(productId: string, productParams?: Stripe.ProductUpdateParams): Promise<Stripe.Response<Stripe.Product>>;
    searchProducts(query: string, limit?: number, expand?: string[]): Promise<Stripe.Response<Stripe.ApiSearchResult<Stripe.Product>>>;
    listAllProducts(active?: boolean, type?: Stripe.ProductListParams.Type, ids?: string[], url?: string, limit?: number, startingAfter?: string, endingBefore?: string, expand?: string[]): Promise<Stripe.Response<Stripe.ApiList<Stripe.Product>>>;
    deleteProduct(productId: string): Promise<Stripe.Response<Stripe.DeletedProduct>>;
    createBankAccountToken(bankAccountTokenParams: Stripe.TokenCreateParams): Promise<Stripe.Response<Stripe.Token>>;
    createAccount(accountParams: Stripe.AccountCreateParams): Promise<Stripe.Response<Stripe.Account>>;
    retrieveAccount(accountId: string): Promise<Stripe.Response<Stripe.Account>>;
    updateAccount(accountId: string, accountParams: Stripe.AccountUpdateParams): Promise<Stripe.Response<Stripe.Account>>;
    rejectAccount(accountId: string, accountRejectedParams: Stripe.AccountRejectParams): Promise<Stripe.Response<Stripe.Account>>;
    deleteAccount(accountId: string, accountDeleteParams?: Stripe.AccountDeleteParams): Promise<Stripe.Response<Stripe.DeletedAccount>>;
    createAccountLink(accountLinkParams: Stripe.AccountLinkCreateParams): Promise<Stripe.Response<Stripe.AccountLink>>;
    createTransfer(transferParams: Stripe.TransferCreateParams): Promise<Stripe.Response<Stripe.Transfer>>;
    retrieveTransfer(transferId: string): Promise<Stripe.Response<Stripe.Transfer>>;
    updateTransfer(transferId: string, transferParams: Stripe.TransferUpdateParams): Promise<Stripe.Response<Stripe.Transfer>>;
}
export { BaseStripeService, StripeService };
